You are receiving this mail as a port that you maintain
is failing to build on the FreeBSD package build server.
Please investigate the failure and submit a PR to fix
build.

Maintainer:     [email protected]
Log URL:        
https://pkg-status.freebsd.org/ampere2/data/main-arm64-default/p4af0312316c9_s5a2328a1785/logs/beats94-9.4.1_5.log
Build URL:      
https://pkg-status.freebsd.org/ampere2/build.html?mastername=main-arm64-default&build=p4af0312316c9_s5a2328a1785
Log:

=>> Building sysutils/beats94
build started at Mon Sep 28 20:58:40 UTC 2026
port directory: /usr/ports/sysutils/beats94
package name: beats94-9.4.1_5
building for: FreeBSD main-arm64-default-job-10 16.0-CURRENT FreeBSD 
16.0-CURRENT 1600026 arm64
maintained by: [email protected]
Makefile datestamp: -rw-r--r--  1 root wheel 6068 Sep 10 01:08 
/usr/ports/sysutils/beats94/Makefile
Ports top last git commit: 4af0312316c9ede1507ec0c36c3064c24df8b848
Ports top unclean checkout: no
Port dir last git commit: dd0905142a9a35cdf8267e2706db9488b516ad01
Port dir unclean checkout: no
Poudriere version: poudriere-git-3.4.8-3-gd92fb7c0
Host OSVERSION: 1600022
Jail OSVERSION: 1600026
Job Id: 10




!!! Jail is newer than host. (Jail: 1600026, Host: 1600022) !!!
!!! This is not supported. !!!
!!! Host kernel must be same or newer than jail. !!!
!!! Expect build failures. !!!



---Begin Environment---
SHELL=/bin/sh
OSVERSION=1600026
UNAME_v=FreeBSD 16.0-CURRENT 1600026
UNAME_r=16.0-CURRENT
BLOCKSIZE=K
MAIL=/var/mail/root
MM_CHARSET=UTF-8
LANG=C.UTF-8
STATUS=1
HOME=/root
PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
MAKE_OBJDIR_CHECK_WRITABLE=0
LOCALBASE=/usr/local
USER=root
POUDRIERE_NAME=poudriere-git
LIBEXECPREFIX=/usr/local/libexec/poudriere
POUDRIERE_VERSION=3.4.8-3-gd92fb7c0
MASTERMNT=/usr/local/poudriere/data/.m/main-arm64-default/ref
LC_COLLATE=C
POUDRIERE_BUILD_TYPE=bulk
PACKAGE_BUILDING=yes
SAVED_TERM=
OUTPUT_REDIRECTED_STDERR=4
OUTPUT_REDIRECTED=1
PWD=/usr/local/poudriere/data/.m/main-arm64-default/10/.p
OUTPUT_REDIRECTED_STDOUT=3
P_PORTS_FEATURES=FLAVORS SUBPACKAGES SELECTED_OPTIONS
MASTERNAME=main-arm64-default
SCRIPTPREFIX=/usr/local/share/poudriere
SCRIPTNAME=bulk.sh
OLDPWD=/usr/local/poudriere/data/.m/main-arm64-default/ref/.p/pool
POUDRIERE_PKGNAME=poudriere-git-3.4.8-3-gd92fb7c0
SCRIPTPATH=/usr/local/share/poudriere/bulk.sh
POUDRIEREPATH=/usr/local/bin/poudriere
---End Environment---

---Begin Poudriere Port Flags/Env---
PORT_FLAGS=
PKGENV=
FLAVOR=
MAKE_ARGS=
---End Poudriere Port Flags/Env---

---Begin OPTIONS List---
===> The following configuration options are available for beats94-9.4.1_5:
     AUDITBEAT=off: Auditbeat
     FILEBEAT=on: Filebeat
     HEARTBEAT=on: Heartbeat
     METRICBEAT=on: Metricbeat
     PACKETBEAT=off: Packetbeat
===> Use 'make config' to modify these settings
---End OPTIONS List---

--MAINTAINER--
[email protected]
--End MAINTAINER--

--CONFIGURE_ARGS--

--End CONFIGURE_ARGS--

--CONFIGURE_ENV--
XDG_DATA_HOME=/wrkdirs/usr/ports/sysutils/beats94/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/sysutils/beats94/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/sysutils/beats94/work/.cache  
HOME=/wrkdirs/usr/ports/sysutils/beats94/work TMPDIR="/tmp" 
PATH=/wrkdirs/usr/ports/sysutils/beats94/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/sysutils/beats94/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 SHELL=/bin/sh CONFIG_SHELL=/bin/sh
--End CONFIGURE_ENV--

--MAKE_ENV--
GOBUILD_FLAGS="-mod=vendor" 
XDG_DATA_HOME=/wrkdirs/usr/ports/sysutils/beats94/work  
XDG_CONFIG_HOME=/wrkdirs/usr/ports/sysutils/beats94/work  
XDG_CACHE_HOME=/wrkdirs/usr/ports/sysutils/beats94/work/.cache  
HOME=/wrkdirs/usr/ports/sysutils/beats94/work TMPDIR="/tmp" 
PATH=/wrkdirs/usr/ports/sysutils/beats94/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin:/root/bin
 
PKG_CONFIG_LIBDIR=/wrkdirs/usr/ports/sysutils/beats94/work/.pkgconfig:/usr/local/libdata/pkgconfig:/usr/local/share/pkgconfig:/usr/libdata/pkgconfig
 MK_DEBUG_FILES=no MK_KERNEL_SYMBOLS=no SHELL=/bin/sh NO_LINT=YES 
PREFIX=/usr/local  LOCALBASE=/usr/local  CC="cc" CFLAGS="-O2 -pipe  
-fstack-protector-strong -fno-strict-aliasing "  CPP="cpp" CPPFLAGS=""  
LDFLAGS=" -Wl,--fix-cortex-a53-843419 " LIBS=""  CXX="c++" CXXFLAGS="-O2 -pipe 
-fstack-protector-strong -fno-strict-aliasing   " BSD_INSTALL_PROGRAM="install  
-s -m 555"  BSD_INSTALL_LIB="install  -s -m 0644"  BSD_INSTALL_SCRIPT="install  
-m 555" 
 BSD_INSTALL_DATA="install  -m 0644"  BSD_INSTALL_MAN="install  -m 444"
--End MAKE_ENV--

--PLIST_SUB--
 AUDITBEAT="@comment " NO_AUDITBEAT="" FILEBEAT="" NO_FILEBEAT="@comment " 
HEARTBEAT="" NO_HEARTBEAT="@comment " METRICBEAT="" NO_METRICBEAT="@comment " 
PACKETBEAT="@comment " NO_PACKETBEAT="" OSREL=16.0 PREFIX=%D 
LOCALBASE=/usr/local  RESETPREFIX=/usr/local LIB32DIR=lib 
DOCSDIR="share/doc/beats"  EXAMPLESDIR="share/examples/beats"  
DATADIR="share/beats"  WWWDIR="www/beats"  ETCDIR="etc/beats"
--End PLIST_SUB--

--SUB_LIST--
 AUDITBEAT="@comment " NO_AUDITBEAT="" FILEBEAT="" NO_FILEBEAT="@comment " 
HEARTBEAT="" NO_HEARTBEAT="@comment " METRICBEAT="" NO_METRICBEAT="@comment " 
PACKETBEAT="@comment " NO_PACKETBEAT="" PREFIX=/usr/local LOCALBASE=/usr/local  
DATADIR=/usr/local/share/beats DOCSDIR=/usr/local/share/doc/beats 
EXAMPLESDIR=/usr/local/share/examples/beats  WWWDIR=/usr/local/www/beats 
ETCDIR=/usr/local/etc/beats
--End SUB_LIST--

---Begin make.conf---
USE_PACKAGE_DEPENDS=yes
BATCH=yes
WRKDIRPREFIX=/wrkdirs
PORTSDIR=/usr/ports
PACKAGES=/packages
DISTDIR=/distfiles
PACKAGE_BUILDING=yes
PACKAGE_BUILDING_FLAVORS=yes
####  ####
# XXX: We really need this but cannot use it while 'make checksum' does not
# try the next mirror on checksum failure.  It currently retries the same
# failed mirror and then fails rather then trying another.  It *does*
# try the next if the size is mismatched though.
#MASTER_SITE_FREEBSD=yes
# Build ALLOW_MAKE_JOBS_PACKAGES with 3 jobs
MAKE_JOBS_NUMBER=3
#### Misc Poudriere ####
.include "/etc/make.conf.ports_env"
GID=0
UID=0
---End make.conf---
--Resource limits--
cpu time               (seconds, -t)  unlimited
file size           (512-blocks, -f)  unlimited
data seg size           (kbytes, -d)  1048576
stack size              (kbytes, -s)  1048576
core file size      (512-blocks, -c)  unlimited
max memory size         (kbytes, -m)  unlimited
locked memory           (kbytes, -l)  unlimited
max user processes              (-u)  89999
open files                      (-n)  8192
virtual mem size        (kbytes, -v)  unlimited
swap limit              (kbytes, -w)  unlimited
socket buffer size       (bytes, -b)  unlimited
pseudo-terminals                (-p)  unlimited
kqueues                         (-k)  unlimited
umtx shared locks               (-o)  unlimited
pipebuf                 (kbytes, -y)  unlimited
virtual machines                (-V)  unlimited
--End resource limits--
=======================<phase: check-sanity   >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 accepted by the user
===========================================================================
=======================<phase: pkg-depends    >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===>   beats94-9.4.1_5 depends on file: /usr/local/sbin/pkg - not found
===>   Installing existing package /packages/All/pkg-2.8.4.pkg
[main-arm64-default-job-10] Installing pkg-2.8.4...
[main-arm64-default-job-10] Extracting pkg-2.8.4: .......... done
===>   beats94-9.4.1_5 depends on file: /usr/local/sbin/pkg - found
===>   Returning to build of beats94-9.4.1_5
===========================================================================
=======================<phase: fetch-depends  >============================
===== env: USE_PACKAGE_DEPENDS_ONLY=1 USER=root UID=0 GID=0
===>   beats94-9.4.1_5 depends on file: /usr/local/bin/go126 - not found
===>   Installing existing package /packages/All/go126-1.26.8.pkg
[main-arm64-default-job-10] Installing go126-1.26.8...
[main-arm64-default-job-10] `-- Installing binutils-2.44,1...
[main-arm64-default-job-10] |   `-- Installing indexinfo-0.3.1_1...
[main-arm64-default-job-10] |   `-- Extracting indexinfo-0.3.1_1: .... done
[main-arm64-default-job-10] |   `-- Installing zstd-1.5.7_2...
[main-arm64-default-job-10] |   | `-- Installing liblz4-1.10.0_2,1...
[main-arm64-default-job-10] |   | `-- Extracting liblz4-1.10.0_2,1: .......... 
done
[main-arm64-default-job-10] |   `-- Extracting zstd-1.5.7_2: .......... done
[main-arm64-default-job-10] `-- Extracting binutils-2.44,1: .......... done
[main-arm64-default-job-10] Extracting go126-1.26.8: .......... done
===>   beats94-9.4.1_5 depends on file: /usr/local/bin/go126 - found
===>   Returning to build of beats94-9.4.1_5
===========================================================================
=======================<phase: fetch          >============================
===== env: NO_DEPENDS=yes USER=root UID=0 GID=0
===>  License APACHE20 accepted by the user
===> Fetching all distfiles required by beats94-9.4.1_5 for building
===> Fetching github.com/elastic/beats/v7 dependencies
# get 
https://proxy.golang.org/github.com/%21azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice/v4/@v/v4.8.0.mod
# get https://proxy.golang.org/al.essio.dev/pkg/shellescape/@v/v1.5.1.mod
# get 
https://proxy.golang.org/aqwari.net/xml/@v/v0.0.0-20210331023308-d9421b293817.mod
# get https://proxy.golang.org/cel.dev/expr/@v/v0.25.1.mod
# get https://proxy.golang.org/cloud.google.com/go/@v/v0.123.0.mod
# get https://proxy.golang.org/cloud.google.com/go/auth/@v/v0.18.2.mod
# get 
https://proxy.golang.org/cloud.google.com/go/auth/oauth2adapt/@v/v0.2.8.mod
# get https://proxy.golang.org/cloud.google.com/go/bigquery/@v/v1.73.1.mod
# get https://proxy.golang.org/cloud.google.com/go/compute/@v/v1.54.0.mod
# get 
https://proxy.golang.org/cloud.google.com/go/compute/metadata/@v/v0.9.0.mod
# get https://proxy.golang.org/cloud.google.com/go/iam/@v/v1.5.3.mod
# get https://proxy.golang.org/cloud.google.com/go/longrunning/@v/v0.8.0.mod
# get https://proxy.golang.org/cloud.google.com/go/monitoring/@v/v1.24.3.mod
# get https://proxy.golang.org/cloud.google.com/go/pubsub/@v/v1.50.1.mod
# get https://proxy.golang.org/cloud.google.com/go/pubsub/v2/@v/v2.0.0.mod
# get https://proxy.golang.org/cloud.google.com/go/redis/@v/v1.18.3.mod
# get https://proxy.golang.org/cloud.google.com/go/storage/@v/v1.59.0.mod
# get 
https://proxy.golang.org/code.cloudfoundry.org/go-diodes/@v/v0.0.0-20190809170250-f77fb823c7ee.mod
# get 
https://proxy.golang.org/code.cloudfoundry.org/go-loggregator/@v/v7.4.0+incompatible.mod
<snip>
# get https://proxy.golang.org/golang.org/x/image/@v/v0.25.0.zip
# get https://proxy.golang.org/golang.org/x/mod/@v/v0.34.0.zip
# get https://proxy.golang.org/golang.org/x/net/@v/v0.52.0.zip
# get https://proxy.golang.org/golang.org/x/oauth2/@v/v0.36.0.zip
# get https://proxy.golang.org/golang.org/x/crypto/@v/v0.49.0.zip: 200 OK 
(0.133s)
# get https://proxy.golang.org/golang.org/x/mod/@v/v0.34.0.zip: 200 OK (0.093s)
# get https://proxy.golang.org/golang.org/x/oauth2/@v/v0.36.0.zip: 200 OK 
(0.079s)
# get https://proxy.golang.org/golang.org/x/image/@v/v0.25.0.zip: 200 OK 
(0.097s)
# get https://proxy.golang.org/golang.org/x/arch/@v/v0.25.0.zip: 200 OK (0.158s)
# get https://proxy.golang.org/golang.org/x/sync/@v/v0.20.0.zip
# get https://proxy.golang.org/golang.org/x/sys/@v/v0.42.0.zip
# get 
https://proxy.golang.org/golang.org/x/telemetry/@v/v0.0.0-20260311193753-579e4da9a98c.zip
# get https://proxy.golang.org/golang.org/x/term/@v/v0.41.0.zip
# get 
https://proxy.golang.org/golang.org/x/exp/@v/v0.0.0-20260312153236-7ab1446f8b90.zip:
 200 OK (0.228s)
# get https://proxy.golang.org/golang.org/x/net/@v/v0.52.0.zip: 200 OK (0.224s)
# get https://proxy.golang.org/golang.org/x/text/@v/v0.35.0.zip
# get 
https://proxy.golang.org/golang.org/x/lint/@v/v0.0.0-20200302205851-738671d3881b.zip:
 200 OK (0.284s)
# get https://proxy.golang.org/golang.org/x/time/@v/v0.15.0.zip
# get https://proxy.golang.org/golang.org/x/tools/@v/v0.43.0.zip
# get 
https://proxy.golang.org/golang.org/x/tools/go/expect/@v/v0.1.1-deprecated.zip
# get 
https://proxy.golang.org/golang.org/x/tools/go/packages/packagestest/@v/v0.1.1-deprecated.zip
# get 
https://proxy.golang.org/golang.org/x/xerrors/@v/v0.0.0-20240903120638-7835f813f4da.zip
# get https://proxy.golang.org/golang.org/x/sync/@v/v0.20.0.zip: 200 OK (0.321s)
# get https://proxy.golang.org/golang.org/x/text/@v/v0.35.0.zip: 200 OK (0.205s)
# get https://proxy.golang.org/golang.org/x/term/@v/v0.41.0.zip: 200 OK (0.275s)
# get 
https://proxy.golang.org/golang.org/x/tools/go/expect/@v/v0.1.1-deprecated.zip: 
200 OK (0.190s)
# get https://proxy.golang.org/golang.org/x/time/@v/v0.15.0.zip: 200 OK (0.196s)
# get 
https://proxy.golang.org/golang.org/x/tools/go/packages/packagestest/@v/v0.1.1-deprecated.zip:
 200 OK (0.177s)
# get https://proxy.golang.org/gonum.org/v1/gonum/@v/v0.17.0.zip
# get https://proxy.golang.org/gonum.org/v1/plot/@v/v0.15.2.zip
# get https://proxy.golang.org/golang.org/x/tools/@v/v0.43.0.zip: 200 OK 
(0.200s)
# get 
https://proxy.golang.org/golang.org/x/xerrors/@v/v0.0.0-20240903120638-7835f813f4da.zip:
 200 OK (0.107s)
# get https://proxy.golang.org/golang.org/x/sys/@v/v0.42.0.zip: 200 OK (0.325s)
# get 
https://proxy.golang.org/gonum.org/v1/tools/@v/v0.0.0-20200318103217-c168b003ce8c.zip
# get https://proxy.golang.org/google.golang.org/appengine/@v/v1.6.8.zip
# get https://proxy.golang.org/google.golang.org/api/@v/v0.272.0.zip
# get 
https://proxy.golang.org/google.golang.org/genproto/@v/v0.0.0-20260217215200-42d3e9bedb6d.zip
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/api/@v/v0.0.0-20260406210006-6f92a3bedf2d.zip
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/bytestream/@v/v0.0.0-20260311181403-84a4fc48630c.zip
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/rpc/@v/v0.0.0-20260406210006-6f92a3bedf2d.zip
# get https://proxy.golang.org/google.golang.org/grpc/@v/v1.80.0.zip
# get 
https://proxy.golang.org/golang.org/x/telemetry/@v/v0.0.0-20260311193753-579e4da9a98c.zip:
 200 OK (0.560s)
# get 
https://proxy.golang.org/google.golang.org/grpc/examples/@v/v0.0.0-20250407062114-b368379ef8f6.zip
# get https://proxy.golang.org/google.golang.org/protobuf/@v/v1.36.11.zip
# get https://proxy.golang.org/gopkg.in/alecthomas/kingpin.v2/@v/v2.2.6.zip
# get 
https://proxy.golang.org/gopkg.in/check.v1/@v/v1.0.0-20201130134442-10cb98267c6c.zip
# get https://proxy.golang.org/gonum.org/v1/gonum/@v/v0.17.0.zip: 200 OK 
(0.301s)
# get https://proxy.golang.org/gopkg.in/evanphx/json-patch.v4/@v/v4.13.0.zip
# get 
https://proxy.golang.org/gonum.org/v1/tools/@v/v0.0.0-20200318103217-c168b003ce8c.zip:
 200 OK (0.306s)
# get https://proxy.golang.org/gopkg.in/alecthomas/kingpin.v2/@v/v2.2.6.zip: 
200 OK (0.050s)
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/rpc/@v/v0.0.0-20260406210006-6f92a3bedf2d.zip:
 200 OK (0.099s)
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/api/@v/v0.0.0-20260406210006-6f92a3bedf2d.zip:
 200 OK (0.208s)
# get https://proxy.golang.org/google.golang.org/appengine/@v/v1.6.8.zip: 200 
OK (0.283s)
# get https://proxy.golang.org/gopkg.in/fsnotify.v1/@v/v1.4.7.zip
# get https://proxy.golang.org/google.golang.org/protobuf/@v/v1.36.11.zip: 200 
OK (0.068s)
# get https://proxy.golang.org/google.golang.org/grpc/@v/v1.80.0.zip: 200 OK 
(0.073s)
# get 
https://proxy.golang.org/google.golang.org/genproto/@v/v0.0.0-20260217215200-42d3e9bedb6d.zip:
 200 OK (0.239s)
# get 
https://proxy.golang.org/google.golang.org/grpc/examples/@v/v0.0.0-20250407062114-b368379ef8f6.zip:
 200 OK (0.068s)
# get https://proxy.golang.org/gopkg.in/fsnotify.v1/@v/v1.4.7.zip: 200 OK 
(0.391s)
# get https://proxy.golang.org/gopkg.in/evanphx/json-patch.v4/@v/v4.13.0.zip: 
200 OK (0.401s)
# get 
https://proxy.golang.org/gopkg.in/check.v1/@v/v1.0.0-20201130134442-10cb98267c6c.zip:
 200 OK (0.411s)
# get 
https://proxy.golang.org/google.golang.org/genproto/googleapis/bytestream/@v/v0.0.0-20260311181403-84a4fc48630c.zip:
 200 OK (0.580s)
# get https://proxy.golang.org/gopkg.in/h2non/gock.v1/@v/v1.1.2.zip
# get https://proxy.golang.org/gopkg.in/inf.v0/@v/v0.9.1.zip
# get https://proxy.golang.org/gopkg.in/hjson/hjson-go.v3/@v/v3.0.1.zip
# get https://proxy.golang.org/gopkg.in/h2non/gock.v1/@v/v1.1.2.zip: 200 OK 
(0.501s)
# get https://proxy.golang.org/gopkg.in/ini.v1/@v/v1.67.1.zip
# get https://proxy.golang.org/gopkg.in/mcuadros/go-syslog.v2/@v/v2.3.0.zip
# get https://proxy.golang.org/gopkg.in/inf.v0/@v/v0.9.1.zip: 200 OK (0.497s)
# get https://proxy.golang.org/gopkg.in/natefinch/lumberjack.v2/@v/v2.2.1.zip
# get 
https://proxy.golang.org/gopkg.in/tomb.v1/@v/v1.0.0-20141024135613-dd632973f1e7.zip
# get 
https://proxy.golang.org/gopkg.in/yaml.v1/@v/v1.0.0-20140924161607-9f9df34309c0.zip
# get https://proxy.golang.org/gopkg.in/yaml.v2/@v/v2.4.0.zip
# get https://proxy.golang.org/gopkg.in/hjson/hjson-go.v3/@v/v3.0.1.zip: 200 OK 
(0.596s)
# get https://proxy.golang.org/gopkg.in/yaml.v3/@v/v3.0.1.zip
# get https://proxy.golang.org/gotest.tools/gotestsum/@v/v1.7.0.zip
# get https://proxy.golang.org/google.golang.org/api/@v/v0.272.0.zip: 200 OK 
(1.290s)
# get https://proxy.golang.org/gopkg.in/natefinch/lumberjack.v2/@v/v2.2.1.zip: 
200 OK (0.121s)
# get https://proxy.golang.org/gotest.tools/v3/@v/v3.5.1.zip
# get 
https://proxy.golang.org/honnef.co/go/tools/@v/v0.0.0-20190523083050-ea95bdfd59fc.zip
# get 
https://proxy.golang.org/gopkg.in/tomb.v1/@v/v1.0.0-20141024135613-dd632973f1e7.zip:
 200 OK (0.180s)
# get 
https://proxy.golang.org/gopkg.in/yaml.v1/@v/v1.0.0-20140924161607-9f9df34309c0.zip:
 200 OK (0.156s)
# get https://proxy.golang.org/howett.net/plist/@v/v1.0.1.zip
# get https://proxy.golang.org/k8s.io/api/@v/v0.35.3.zip
# get https://proxy.golang.org/gonum.org/v1/plot/@v/v0.15.2.zip: 200 OK (1.361s)
# get https://proxy.golang.org/k8s.io/apimachinery/@v/v0.35.3.zip
# get https://proxy.golang.org/gopkg.in/yaml.v3/@v/v3.0.1.zip: 200 OK (0.223s)
# get https://proxy.golang.org/gopkg.in/ini.v1/@v/v1.67.1.zip: 200 OK (0.333s)
# get https://proxy.golang.org/gopkg.in/yaml.v2/@v/v2.4.0.zip: 200 OK (0.321s)
# get https://proxy.golang.org/gotest.tools/gotestsum/@v/v1.7.0.zip: 200 OK 
(0.287s)
# get https://proxy.golang.org/k8s.io/apiserver/@v/v0.32.3.zip
# get https://proxy.golang.org/k8s.io/client-go/@v/v0.35.3.zip
# get https://proxy.golang.org/gopkg.in/mcuadros/go-syslog.v2/@v/v2.3.0.zip: 
200 OK (0.767s)
# get https://proxy.golang.org/k8s.io/cri-api/@v/v0.32.3.zip
# get 
https://proxy.golang.org/k8s.io/gengo/v2/@v/v2.0.0-20250604051438-85fd79dbfd9f.zip
# get https://proxy.golang.org/k8s.io/klog/@v/v1.0.0.zip
# get https://proxy.golang.org/k8s.io/klog/v2/@v/v2.140.0.zip
# get 
https://proxy.golang.org/k8s.io/kube-openapi/@v/v0.0.0-20250910181357-589584f1c912.zip
# get https://proxy.golang.org/k8s.io/kubelet/@v/v0.32.3.zip
# get 
https://proxy.golang.org/k8s.io/utils/@v/v0.0.0-20251002143259-bc988d571ff4.zip
# get https://proxy.golang.org/gotest.tools/v3/@v/v3.5.1.zip: 200 OK (0.943s)
# get https://proxy.golang.org/k8s.io/api/@v/v0.35.3.zip: 200 OK (0.883s)
# get https://proxy.golang.org/k8s.io/apiserver/@v/v0.32.3.zip: 200 OK (0.369s)
# get https://proxy.golang.org/k8s.io/apimachinery/@v/v0.35.3.zip: 200 OK 
(0.818s)
# get 
https://proxy.golang.org/honnef.co/go/tools/@v/v0.0.0-20190523083050-ea95bdfd59fc.zip:
 200 OK (0.942s)
# get https://proxy.golang.org/howett.net/plist/@v/v1.0.1.zip: 200 OK (0.904s)
# get https://proxy.golang.org/k8s.io/cri-api/@v/v0.32.3.zip: 200 OK (0.357s)
# get 
https://proxy.golang.org/kernel.org/pub/linux/libs/security/libcap/cap/@v/v1.2.57.zip
# get https://proxy.golang.org/k8s.io/klog/@v/v1.0.0.zip: 200 OK (0.495s)
# get 
https://proxy.golang.org/kernel.org/pub/linux/libs/security/libcap/psx/@v/v1.2.57.zip
# get https://proxy.golang.org/k8s.io/klog/v2/@v/v2.140.0.zip: 200 OK (0.986s)
# get https://proxy.golang.org/k8s.io/kubelet/@v/v0.32.3.zip: 200 OK (0.960s)
# get https://proxy.golang.org/k8s.io/client-go/@v/v0.35.3.zip: 200 OK (1.290s)
# get 
https://proxy.golang.org/k8s.io/gengo/v2/@v/v2.0.0-20250604051438-85fd79dbfd9f.zip:
 200 OK (1.273s)
# get 
https://proxy.golang.org/k8s.io/kube-openapi/@v/v0.0.0-20250910181357-589584f1c912.zip:
 200 OK (1.160s)
# get https://proxy.golang.org/lukechampine.com/uint128/@v/v1.3.0.zip
# get 
https://proxy.golang.org/k8s.io/utils/@v/v0.0.0-20251002143259-bc988d571ff4.zip:
 200 OK (0.960s)
# get https://proxy.golang.org/modernc.org/cc/v3/@v/v3.40.0.zip
# get https://proxy.golang.org/modernc.org/ccgo/v3/@v/v3.16.13.zip
# get 
https://proxy.golang.org/modernc.org/gc/v3/@v/v3.0.0-20240107210532-573471604cb6.zip
# get 
https://proxy.golang.org/kernel.org/pub/linux/libs/security/libcap/psx/@v/v1.2.57.zip:
 200 OK (0.860s)
# get https://proxy.golang.org/modernc.org/libc/@v/v1.41.0.zip
# get https://proxy.golang.org/lukechampine.com/uint128/@v/v1.3.0.zip: 200 OK 
(0.142s)
# get https://proxy.golang.org/modernc.org/mathutil/@v/v1.6.0.zip
# get https://proxy.golang.org/modernc.org/memory/@v/v1.7.2.zip
# get https://proxy.golang.org/modernc.org/opt/@v/v0.1.3.zip
# get https://proxy.golang.org/modernc.org/sqlite/@v/v1.29.6.zip
# get https://proxy.golang.org/modernc.org/strutil/@v/v1.2.0.zip
# get https://proxy.golang.org/modernc.org/token/@v/v1.1.0.zip
# get 
https://proxy.golang.org/kernel.org/pub/linux/libs/security/libcap/cap/@v/v1.2.57.zip:
 200 OK (1.253s)
# get https://proxy.golang.org/mvdan.cc/garble/@v/v0.12.1.zip
# get https://proxy.golang.org/rsc.io/pdf/@v/v0.1.1.zip
# get 
https://proxy.golang.org/sigs.k8s.io/json/@v/v0.0.0-20250730193827-2d320260d730.zip
# get https://proxy.golang.org/modernc.org/cc/v3/@v/v3.40.0.zip: 200 OK (2.679s)
# get https://proxy.golang.org/sigs.k8s.io/kind/@v/v0.29.0.zip
# get https://proxy.golang.org/sigs.k8s.io/randfill/@v/v1.0.0.zip
# get 
https://proxy.golang.org/sigs.k8s.io/structured-merge-diff/v4/@v/v4.4.2.zip
# get 
https://proxy.golang.org/modernc.org/gc/v3/@v/v3.0.0-20240107210532-573471604cb6.zip:
 200 OK (2.669s)
# get https://proxy.golang.org/modernc.org/memory/@v/v1.7.2.zip: 200 OK (2.568s)
# get https://proxy.golang.org/modernc.org/strutil/@v/v1.2.0.zip: 200 OK 
(2.427s)
# get https://proxy.golang.org/modernc.org/ccgo/v3/@v/v3.16.13.zip: 200 OK 
(2.713s)
# get https://proxy.golang.org/modernc.org/libc/@v/v1.41.0.zip: 200 OK (2.613s)
# get 
https://proxy.golang.org/sigs.k8s.io/json/@v/v0.0.0-20250730193827-2d320260d730.zip:
 200 OK (0.068s)
# get https://proxy.golang.org/modernc.org/mathutil/@v/v1.6.0.zip: 200 OK 
(2.611s)
# get https://proxy.golang.org/modernc.org/token/@v/v1.1.0.zip: 200 OK (2.330s)
# get https://proxy.golang.org/rsc.io/pdf/@v/v0.1.1.zip: 200 OK (2.095s)
# get 
https://proxy.golang.org/sigs.k8s.io/structured-merge-diff/v6/@v/v6.3.0.zip
# get https://proxy.golang.org/sigs.k8s.io/yaml/@v/v1.6.0.zip
# get https://proxy.golang.org/modernc.org/sqlite/@v/v1.29.6.zip: 200 OK 
(2.683s)
# get https://proxy.golang.org/sigs.k8s.io/randfill/@v/v1.0.0.zip: 200 OK 
(0.253s)
# get 
https://proxy.golang.org/tags.cncf.io/container-device-interface/specs-go/@v/v1.0.0.zip
# get 
https://proxy.golang.org/sigs.k8s.io/structured-merge-diff/v4/@v/v4.4.2.zip: 
200 OK (0.257s)
# get https://proxy.golang.org/www.velocidex.com/golang/go-ntfs/@v/v0.1.1.zip
# get 
https://proxy.golang.org/tags.cncf.io/container-device-interface/@v/v1.0.1.zip
# get 
https://proxy.golang.org/www.velocidex.com/golang/regparser/@v/v0.0.0-20250203141505-31e704a67ef7.zip
# get https://proxy.golang.org/modernc.org/opt/@v/v0.1.3.zip: 200 OK (3.223s)
# get 
https://proxy.golang.org/sigs.k8s.io/structured-merge-diff/v6/@v/v6.3.0.zip: 
200 OK (0.652s)
# get https://proxy.golang.org/sigs.k8s.io/yaml/@v/v1.6.0.zip: 200 OK (0.651s)
# get https://proxy.golang.org/mvdan.cc/garble/@v/v0.12.1.zip: 200 OK (2.762s)
# get https://proxy.golang.org/www.velocidex.com/golang/go-ntfs/@v/v0.1.1.zip: 
200 OK (1.842s)
# get 
https://proxy.golang.org/www.velocidex.com/golang/regparser/@v/v0.0.0-20250203141505-31e704a67ef7.zip:
 200 OK (1.812s)
# get 
https://proxy.golang.org/tags.cncf.io/container-device-interface/@v/v1.0.1.zip: 
200 OK (1.841s)
# get 
https://proxy.golang.org/tags.cncf.io/container-device-interface/specs-go/@v/v1.0.0.zip:
 200 OK (1.871s)
# get https://proxy.golang.org/sigs.k8s.io/kind/@v/v0.29.0.zip: 200 OK (2.347s)
go: al.essio.dev/pkg/[email protected]: verifying go.mod: 
al.essio.dev/pkg/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/al.essio.dev/pkg/[email protected]": EOF
go: aqwari.net/[email protected]: verifying go.mod: 
aqwari.net/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/aqwari.net/[email protected]":
 net/http: TLS handshake timeout
go: cel.dev/[email protected]: verifying go.mod: cel.dev/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cel.dev/[email protected]": EOF
go: cloud.google.com/[email protected]: verifying go.mod: 
cloud.google.com/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": net/http: TLS 
handshake timeout
go: cloud.google.com/go/auth/[email protected]: verifying go.mod: 
cloud.google.com/go/auth/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/auth/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": net/http: 
TLS handshake timeout
go: cloud.google.com/go/compute/[email protected]: verifying go.mod: 
cloud.google.com/go/compute/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/compute/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": net/http: TLS 
handshake timeout
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": EOF
go: cloud.google.com/go/pubsub/[email protected]: verifying go.mod: 
cloud.google.com/go/pubsub/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/pubsub/[email protected]": EOF
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": net/http: 
TLS handshake timeout
go: cloud.google.com/go/[email protected]: verifying go.mod: 
cloud.google.com/go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/cloud.google.com/go/[email protected]": EOF
go: code.cloudfoundry.org/[email protected]: 
verifying go.mod: 
code.cloudfoundry.org/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/code.cloudfoundry.org/[email protected]":
 EOF
go: code.cloudfoundry.org/[email protected]+incompatible: verifying go.mod: 
code.cloudfoundry.org/[email protected]+incompatible/go.mod: Get 
"https://sum.golang.org/lookup/code.cloudfoundry.org/[email protected]+incompatible":
 net/http: TLS handshake timeout
go: code.cloudfoundry.org/[email protected]: 
verifying go.mod: 
code.cloudfoundry.org/[email protected]/go.mod: 
Get 
"https://sum.golang.org/lookup/code.cloudfoundry.org/[email protected]":
 EOF
go: code.cloudfoundry.org/[email protected]: verifying 
go.mod: 
code.cloudfoundry.org/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/code.cloudfoundry.org/[email protected]":
 EOF
go: filippo.io/[email protected]: verifying go.mod: 
filippo.io/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/filippo.io/[email protected]": EOF
go: github.com/Azure/azure-amqp-common-go/[email protected]: verifying go.mod: 
github.com/Azure/azure-amqp-common-go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-amqp-common-go/[email protected]":
 EOF
go: github.com/Azure/azure-event-hubs-go/[email protected]: verifying go.mod: 
github.com/Azure/azure-event-hubs-go/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-event-hubs-go/[email protected]":
 net/http: TLS handshake timeout
go: github.com/Azure/[email protected]: verifying go.mod: 
github.com/Azure/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/[email protected]": EOF
go: github.com/Azure/[email protected]+incompatible: verifying go.mod: 
github.com/Azure/[email protected]+incompatible/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/[email protected]+incompatible":
 net/http: TLS handshake timeout
go: github.com/Azure/azure-sdk-for-go/sdk/[email protected]: verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/[email protected]":
 net/http: TLS handshake timeout
go: github.com/Azure/azure-sdk-for-go/sdk/[email protected]: verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/[email protected]":
 net/http: TLS handshake timeout
go: github.com/Azure/azure-sdk-for-go/sdk/[email protected]: verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/[email protected]/go.mod: Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/[email protected]":
 EOF
go: github.com/Azure/azure-sdk-for-go/sdk/messaging/azeventhubs/[email protected]: 
verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/messaging/azeventhubs/[email protected]/go.mod: 
Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/messaging/azeventhubs/[email protected]":
 EOF
go: github.com/Azure/azure-sdk-for-go/sdk/monitor/query/[email protected]: 
verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/monitor/query/[email protected]/go.mod: 
Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/monitor/query/[email protected]":
 EOF
go: 
github.com/elastic/azure-sdk-for-go/sdk/resourcemanager/consumption/[email protected]:
 verifying go.mod: 
github.com/elastic/azure-sdk-for-go/sdk/resourcemanager/consumption/[email protected]/go.mod:
 Get 
"https://sum.golang.org/lookup/github.com/elastic/azure-sdk-for-go/sdk/resourcemanager/consumption/[email protected]":
 EOF
go: 
github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice/[email protected]:
 verifying go.mod: 
github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice/[email protected]/go.mod:
 Get 
"https://sum.golang.org/lookup/github.com/!azure/azure-sdk-for-go/sdk/resourcemanager/containerservice/armcontainerservice/[email protected]":
 EOF
*** Error code 1

Stop.
make: stopped making "fetch" in /usr/ports/sysutils/beats94

Reply via email to